Stan Math Library: stan::math::child_type< T > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | List of all members
stan::math::child_type< T > Struct Template Reference

Primary template class for metaprogram to compute child type of T. More...

`#include <child_type.hpp>`

## Public Types
typedef double | type

## Detailed Description

### template<typename T>
struct stan::math::child_type< T >

Primary template class for metaprogram to compute child type of T.

See `test/unit/math/meta/child_type_test.cpp` for intended usage.

Template Parameters

  T | type of container.

Definition at line 19 of file child_type.hpp.

## Member Typedef Documentation

template<typename T >

typedef double stan::math::child_type< T >::type

Definition at line 20 of file child_type.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/scal/meta/child_type.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.